@@ -30,6 +30,7 @@ Currently supported are:
 * Put records to Kinesis Data stream
 * Put records to Kinesis Data Firehose stream
 * Send messages to SQS queues
+* Publish messages on SNS topics
 
 ## Republish a message to another MQTT topic
 
@@ -254,6 +255,26 @@ topic_rule = iot.TopicRule(self, "TopicRule",
     ]
 )
 ```
+
+## Publish messages on an SNS topic
+
+The code snippet below creates and AWS IoT Rule that publishes messages to an SNS topic when it is triggered:
+
+```python
+import aws_cdk.aws_sns as sns
+
+
+topic = sns.Topic(self, "MyTopic")
+
+topic_rule = iot.TopicRule(self, "TopicRule",
+    sql=iot.IotSql.from_string_as_ver20160323("SELECT topic(2) as device_id, year, month, day FROM 'device/+/data'"),
+    actions=[
+        actions.SnsTopicAction(topic,
+            message_format=actions.SnsActionMessageFormat.JSON
+        )
+    ]
+)
+```
 '''
 import abc
 import builtins
@@ -275,6 +296,7 @@ import aws_cdk.aws_kinesisfirehose
 import aws_cdk.aws_lambda
 import aws_cdk.aws_logs
 import aws_cdk.aws_s3
+import aws_cdk.aws_sns
 import aws_cdk.aws_sqs
 
 
@@ -319,7 +341,7 @@ class CloudWatchLogsAction(
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: aws_cdk.aws_iot.ITopicRule) -> aws_cdk.aws_iot.ActionConfig:
-        '''(experimental) (experimental) Returns the topic rule action specification.
+        '''(experimental) Returns the topic rule action specification.
 
         :param rule: -
 
@@ -387,7 +409,7 @@ class CloudWatchPutMetricAction(
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: aws_cdk.aws_iot.ITopicRule) -> aws_cdk.aws_iot.ActionConfig:
-        '''(experimental) (experimental) Returns the topic rule action specification.
+        '''(experimental) Returns the topic rule action specification.
 
         :param rule: -
 
@@ -461,7 +483,7 @@ class CloudWatchSetAlarmStateAction(
         self,
         topic_rule: aws_cdk.aws_iot.ITopicRule,
     ) -> aws_cdk.aws_iot.ActionConfig:
-        '''(experimental) (experimental) Returns the topic rule action specification.
+        '''(experimental) Returns the topic rule action specification.
 
         :param topic_rule: -
 
@@ -580,7 +602,7 @@ class FirehosePutRecordAction(
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: aws_cdk.aws_iot.ITopicRule) -> aws_cdk.aws_iot.ActionConfig:
-        '''(experimental) (experimental) Returns the topic rule action specification.
+        '''(experimental) Returns the topic rule action specification.
 
         :param rule: -
 
@@ -788,7 +810,7 @@ class IotRepublishMqttAction(
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: aws_cdk.aws_iot.ITopicRule) -> aws_cdk.aws_iot.ActionConfig:
-        '''(experimental) (experimental) Returns the topic rule action specification.
+        '''(experimental) Returns the topic rule action specification.
 
         :param rule: -
 
@@ -916,7 +938,7 @@ class KinesisPutRecordAction(
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: aws_cdk.aws_iot.ITopicRule) -> aws_cdk.aws_iot.ActionConfig:
-        '''(experimental) (experimental) Returns the topic rule action specification.
+        '''(experimental) Returns the topic rule action specification.
 
         :param rule: -
 
@@ -1043,7 +1065,7 @@ class LambdaFunctionAction(
         self,
         topic_rule: aws_cdk.aws_iot.ITopicRule,
     ) -> aws_cdk.aws_iot.ActionConfig:
-        '''(experimental) (experimental) Returns the topic rule action specification.
+        '''(experimental) Returns the topic rule action specification.
 
         :param topic_rule: -
 
@@ -1138,7 +1160,7 @@ class S3PutObjectAction(
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: aws_cdk.aws_iot.ITopicRule) -> aws_cdk.aws_iot.ActionConfig:
-        '''(experimental) (experimental) Returns the topic rule action specification.
+        '''(experimental) Returns the topic rule action specification.
 
         :param rule: -
 
@@ -1239,6 +1261,178 @@ class S3PutObjectActionProps(CommonActionProps):
         )
 
 
+@jsii.enum(jsii_type="@aws-cdk/aws-iot-actions.SnsActionMessageFormat")
+class SnsActionMessageFormat(enum.Enum):
+    '''(experimental) SNS topic action message format options.
+
+    :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        import aws_cdk.aws_sns as sns
+        
+        
+        topic = sns.Topic(self, "MyTopic")
+        
+        topic_rule = iot.TopicRule(self, "TopicRule",
+            sql=iot.IotSql.from_string_as_ver20160323("SELECT topic(2) as device_id, year, month, day FROM 'device/+/data'"),
+            actions=[
+                actions.SnsTopicAction(topic,
+                    message_format=actions.SnsActionMessageFormat.JSON
+                )
+            ]
+        )
+    '''
+
+    RAW = "RAW"
+    '''(experimental) RAW message format.
+
+    :stability: experimental
+    '''
+    JSON = "JSON"
+    '''(experimental) JSON message format.
+
+    :stability: experimental
+    '''
+
+
+@jsii.implements(aws_cdk.aws_iot.IAction)
+class SnsTopicAction(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-iot-actions.SnsTopicAction",
+):
+    '''(experimental) The action to write the data from an MQTT message to an Amazon SNS topic.
+
+    :see: https://docs.aws.amazon.com/iot/latest/developerguide/sns-rule-action.html
+    :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        import aws_cdk.aws_sns as sns
+        
+        
+        topic = sns.Topic(self, "MyTopic")
+        
+        topic_rule = iot.TopicRule(self, "TopicRule",
+            sql=iot.IotSql.from_string_as_ver20160323("SELECT topic(2) as device_id, year, month, day FROM 'device/+/data'"),
+            actions=[
+                actions.SnsTopicAction(topic,
+                    message_format=actions.SnsActionMessageFormat.JSON
+                )
+            ]
+        )
+    '''
+
+    def __init__(
+        self,
+        topic: aws_cdk.aws_sns.ITopic,
+        *,
+        message_format: typing.Optional[SnsActionMessageFormat] = None,
+        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+    ) -> None:
+        '''
+        :param topic: The Amazon SNS topic to publish data on. Must not be a FIFO topic.
+        :param message_format: (experimental) The message format of the message to publish. SNS uses this setting to determine if the payload should be parsed and relevant platform-specific bits of the payload should be extracted. Default: SnsActionMessageFormat.RAW
+        :param role: (experimental) The IAM role that allows access to AWS service. Default: a new role will be created
+
+        :stability: experimental
+        '''
+        props = SnsTopicActionProps(message_format=message_format, role=role)
+
+        jsii.create(self.__class__, self, [topic, props])
+
+    @jsii.member(jsii_name="bind")
+    def bind(self, rule: aws_cdk.aws_iot.ITopicRule) -> aws_cdk.aws_iot.ActionConfig:
+        '''(experimental) Returns the topic rule action specification.
+
+        :param rule: -
+
+        :stability: experimental
+        '''
+        return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
+
+
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-iot-actions.SnsTopicActionProps",
+    jsii_struct_bases=[CommonActionProps],
+    name_mapping={"role": "role", "message_format": "messageFormat"},
+)
+class SnsTopicActionProps(CommonActionProps):
+    def __init__(
+        self,
+        *,
+        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        message_format: typing.Optional[SnsActionMessageFormat] = None,
+    ) -> None:
+        '''(experimental) Configuration options for the SNS topic action.
+
+        :param role: (experimental) The IAM role that allows access to AWS service. Default: a new role will be created
+        :param message_format: (experimental) The message format of the message to publish. SNS uses this setting to determine if the payload should be parsed and relevant platform-specific bits of the payload should be extracted. Default: SnsActionMessageFormat.RAW
+
+        :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            import aws_cdk.aws_sns as sns
+            
+            
+            topic = sns.Topic(self, "MyTopic")
+            
+            topic_rule = iot.TopicRule(self, "TopicRule",
+                sql=iot.IotSql.from_string_as_ver20160323("SELECT topic(2) as device_id, year, month, day FROM 'device/+/data'"),
+                actions=[
+                    actions.SnsTopicAction(topic,
+                        message_format=actions.SnsActionMessageFormat.JSON
+                    )
+                ]
+            )
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if role is not None:
+            self._values["role"] = role
+        if message_format is not None:
+            self._values["message_format"] = message_format
+
+    @builtins.property
+    def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+        '''(experimental) The IAM role that allows access to AWS service.
+
+        :default: a new role will be created
+
+        :stability: experimental
+        '''
+        result = self._values.get("role")
+        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+
+    @builtins.property
+    def message_format(self) -> typing.Optional[SnsActionMessageFormat]:
+        '''(experimental) The message format of the message to publish.
+
+        SNS uses this setting to determine if the payload should be parsed and relevant platform-specific bits of the payload should be extracted.
+
+        :default: SnsActionMessageFormat.RAW
+
+        :see: https://docs.aws.amazon.com/sns/latest/dg/sns-message-and-json-formats.html
+        :stability: experimental
+        '''
+        result = self._values.get("message_format")
+        return typing.cast(typing.Optional[SnsActionMessageFormat], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "SnsTopicActionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.implements(aws_cdk.aws_iot.IAction)
 class SqsQueueAction(
     metaclass=jsii.JSIIMeta,
@@ -1286,7 +1480,7 @@ class SqsQueueAction(
 
     @jsii.member(jsii_name="bind")
     def bind(self, rule: aws_cdk.aws_iot.ITopicRule) -> aws_cdk.aws_iot.ActionConfig:
-        '''(experimental) (experimental) Returns the topic rule action specification.
+        '''(experimental) Returns the topic rule action specification.
 
         :param rule: -
 
@@ -1699,6 +1893,9 @@ __all__ = [
     "MqttQualityOfService",
     "S3PutObjectAction",
     "S3PutObjectActionProps",
+    "SnsActionMessageFormat",
+    "SnsTopicAction",
+    "SnsTopicActionProps",
     "SqsQueueAction",
     "SqsQueueActionProps",
 ]
